﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Compute Mismatch Uncertainty (%)
DATE:                  2010-11-10
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       81
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Any requiring computation of basic Source/Load mismatch uncertainty.
#
#  Compatibility:
#        MET/CAL 7.20 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
#  Example 1:
#
# 1.001  MATH         @SourceSWR = 1.2; @LoadSWR = 1.18
# 1.002  CALL         Sub Compute Mismatch Uncertainty (%)
# 1.003  MATH         L[1] = @MismatchUncPct
#
#  Example 2:
#
# 1.001  MATH         @SourceRho = 0.091; @LoadRho = 0.083
# 1.002  CALL         Sub Compute Mismatch Uncertainty (%)
# 1.003  MATH         L[1] = @MismatchUncPct
#
#  Note: In the formulas below, the computed worst-case mismatch uncertainty
#  is considered to have a probability distribution of U-shape density. The
#  computed uncertainty is normalized.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           ISVAR("@SourceSWR") && ISVAR("@LoadSWR")
# Compute gamma value of source.
  1.002  MATH         SourceReflCoeff = (@SourceSWR - 1) / (@SourceSWR + 1)
# Compute gamma value of load.
  1.003  MATH         LoadReflCoeff   = (@LoadSWR   - 1) / (@LoadSWR   + 1)
  1.004  ELSEIF       ISVAR("@SourceRho") && ISVAR("@LoadRho")
  1.005  MATH         SourceReflCoeff = @SourceRho
  1.006  MATH         LoadReflCoeff   = @LoadRho
  1.007  ELSE
  1.008  DISP         Required SWR or Rho value(s) missing or incorrectly
  1.008  DISP         specified.
  1.008  DISP
  1.008  DISP         Press "Terminate" to abort the procedure and correct
  1.008  DISP         the deficiency within the calling procedure.
  1.009  ENDIF

# Compute worst case positive mismatch uncertainty.
  1.010  MATH         UNC1 = ABS((1 + SourceReflCoeff * LoadReflCoeff)^2 - 1)
# Normalize positive mismatch uncertainty and convert to percent.
  1.011  MATH         UNC1 = (UNC1 / SQRT(2)) * 100
# Compute worst case negative mismatch uncertainty.
  1.012  MATH         UNC2 = ABS((1 - SourceReflCoeff * LoadReflCoeff)^2 - 1)
# Normalize negative mismatch uncertainty and convert to percent.
  1.013  MATH         UNC2 = (UNC2 / SQRT(2)) * 100
# Return larger of two computed uncertainties.
  1.014  MATH         @MismatchUncPct = MAX2(UNC1, UNC2)

  1.015  END
